@@ -8,17 +8,16 @@
 # @Description : 包含基本的文件读写，指定扩展名文件查找等基本工具
 
 
-__version__ = "0.14.8"
+__version__ = "0.15.8"
 
 
 import json
 import math
 import random
-import string
 import time
 from typing import List, Union
 
-import emoji
+
 from gitopenlib.utils import basics as gb
 
 
@@ -27,19 +26,6 @@ def list_item_getter(data: list, index: list):
     return [data[idx] for idx in index]
 
 
-def char_is_emoji(character):
-    """判断字符是否是emoji"""
-    return character in emoji.UNICODE_EMOJI
-
-
-def text_has_emoji(text):
-    """判断文本中是否包含emoji"""
-    for character in text:
-        if character in emoji.UNICODE_EMOJI:
-            return True
-    return False
-
-
 def fmt_seconds(seconds: int or float, lang: str = "zh"):
     """把秒转换为年月日小时分钟秒。"""
     if lang == "zh":
@@ -48,11 +34,6 @@ def fmt_seconds(seconds: int or float, lang: str = "zh"):
         return time.strftime("%Y-%m-%d %H:%M:%S", time.gmtime(seconds))
 
 
-def generate_random_strs(length: int):
-    """生成随机字符串"""
-    return "".join(random.sample(string.digits * 5 + string.ascii_letters * 4, length))
-
-
 def list_intersection(listA: list, listB: list):
     """
     求两个list的交集，listA中的哪些元素，在listB中出现了。
@@ -61,24 +42,6 @@ def list_intersection(listA: list, listB: list):
     return [it for it in listA if it in listB]
 
 
-def is_all_chinese(strs: str):
-    """
-    检验是否全是中文字符
-    """
-    for _char in strs:
-        if not "\u4e00" <= _char <= "\u9fa5":
-            return False
-    return True
-
-
-def is_contains_chinese(strs: str):
-    """检验是否含有中文字符"""
-    for _char in strs:
-        if "\u4e00" <= _char <= "\u9fa5":
-            return True
-    return False
-
-
 def dict_extremum(data: dict, type=0) -> tuple:
     """
     找到dict中value的极值，并返回key，若极值有多个，则返回多个key
